@@ -51,7 +51,7 @@ import re
 from collections import OrderedDict
 from Bio import SeqIO
 
-__version__ = '2.0.3'
+__version__ = '2.0.7'
 
 
 def main():
@@ -87,18 +87,20 @@ def main():
         assembly = Assembly(fasta_file)
         best = get_best_locus_match(assembly, ref_seqs, refs, args.threads)
         if best is None:
-            type_gene_results = {}
             best = Locus('None', '', '', [])
-        else:
-            find_assembly_pieces(assembly, best, args)
-            assembly_pieces_fasta = save_assembly_pieces_to_file(best, assembly, args.out)
-            type_gene_results = type_gene_search(assembly_pieces_fasta, type_gene_names, args)
-            if args.no_seq_out and assembly_pieces_fasta is not None:
-                os.remove(assembly_pieces_fasta)
-            protein_blast(assembly, best, gene_seqs, args)
-            apply_special_logic(best, special_logic, ref_genes)
-            if best.type == 'unknown':
-                best.type = 'unknown (' + best.name + ')'
+
+        find_assembly_pieces(assembly, best, args)
+        if not best.assembly_pieces:
+            best = Locus('None', '', '', [])
+
+        assembly_pieces_fasta = save_assembly_pieces_to_file(best, assembly, args.out)
+        type_gene_results = type_gene_search(assembly_pieces_fasta, type_gene_names, args)
+        if args.no_seq_out and assembly_pieces_fasta is not None:
+            os.remove(assembly_pieces_fasta)
+        protein_blast(assembly, best, gene_seqs, args)
+        apply_special_logic(best, special_logic, ref_genes)
+        if best.type == 'unknown':
+            best.type = 'unknown (' + best.name + ')'
 
         output(args.out, assembly, best, args, type_gene_names, type_gene_results,
                json_list, output_table, output_json, all_gene_dict)
@@ -409,8 +411,8 @@ def get_best_locus_match(assembly, refs_fasta, refs, threads):
     """
     Searches for all known locus types in the given assembly and returns the best match.
     Best match is defined as the locus type for which the largest fraction of the locus has a BLAST
-    hit to the assembly. In cases of a tie, the mean identity of the locus type BLAST hits are used
-    to determine the best.
+    hit to the assembly. In cases of a tie, the number of BLAST hits (fewer is better) and the mean
+    identity of the BLAST hits (higher is better) are used to determine the best.
     """
     for ref in refs.values():
         ref.clear()
@@ -420,19 +422,18 @@ def get_best_locus_match(assembly, refs_fasta, refs, threads):
         if hit.qseqid not in refs:
             quit_with_error('BLAST hit (' + hit.qseqid + ') not found in locus references')
         refs[hit.qseqid].add_blast_hit(hit)
-    best_ref = None
-    best_cov = 0.0
     for ref in refs.values():
-        cov = ref.get_coverage()
-        if cov > best_cov:
-            best_cov = cov
-            best_ref = ref
-        elif cov == best_cov and best_ref and \
-                ref.get_mean_blast_hit_identity() > best_ref.get_mean_blast_hit_identity():
-            best_ref = ref
-    if best_ref is not None:
-        best_ref.clean_up_blast_hits()
-    return copy.copy(best_ref)
+        ref.clean_up_blast_hits()
+
+    sorted_refs = sorted(refs.values(), reverse=True,
+                         key=lambda ref: (ref.get_coverage(),
+                                          -len(ref.blast_hits),
+                                          ref.get_mean_blast_hit_identity()))
+    best_ref = sorted_refs[0]
+    if best_ref.get_coverage() == 0.0:
+        return None
+    else:
+        return copy.copy(best_ref)
 
 
 def type_gene_search(assembly_pieces_fasta, type_gene_names, args):
